==> org.eclipse.recommenders.snipmatch.rcp.source_2.1.6.v20140818-1105.jar: org/eclipse/recommenders/internal/snipmatch/rcp/Constants.java <==
/**
 * Copyright (c) 2013 Madhuranga Lakjeewa.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *    Madhuranga Lakjeewa - initial API and implementation.
 */
package org.eclipse.recommenders.internal.snipmatch.rcp;

/**
 * Constant definitions for plug-in preferences, IDs and other constants.
 * <p>
 * Note that UI strings should go into a messages files rather than into this file.
 */
public class Constants {

    public static final String BUNDLE_ID = "org.eclipse.recommenders.snipmatch.rcp"; //$NON-NLS-1$
    public static final String EDITOR_ID = "org.eclipse.recommenders.snipmatch.rcp.editors.snippet"; //$NON-NLS-1$

    public static final String PREF_SNIPPETS_REPO_FETCH_URL = "snippets.repo.url"; //$NON-NLS-1$
    public static final String PREF_SNIPPETS_REPO_PUSH_URL = "snippets.repo.push.url"; //$NON-NLS-1$
    public static final String PREF_SNIPPETS_REPO_PUSH_BRANCH = "snippets.repo.push.branch"; //$NON-NLS-1$
    public static final String PREF_SEARCH_RESULTS_BACKGROUND = "org.eclipse.recommenders.snipmatch.rcp.searchResultBackgroundColor"; //$NON-NLS-1$
    public static final String PREF_SEARCH_BOX_BACKGROUND = "org.eclipse.recommenders.snipmatch.rcp.searchboxbackground"; //$NON-NLS-1$

    public static final String SNIPMATCH_CONTEXT_ID = "Snipmatch-Java-Context"; //$NON-NLS-1$
}

==> org.eclipse.recommenders.snipmatch.rcp.source_2.1.9.v20140917-1240.jar: org/eclipse/recommenders/internal/snipmatch/rcp/Constants.java <==
/**
 * Copyright (c) 2013 Madhuranga Lakjeewa.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *    Madhuranga Lakjeewa - initial API and implementation.
 */
package org.eclipse.recommenders.internal.snipmatch.rcp;

/**
 * Constant definitions for plug-in preferences, IDs and other constants.
 * <p>
 * Note that UI strings should go into a messages files rather than into this file.
 */
public class Constants {

    public static final String BUNDLE_ID = "org.eclipse.recommenders.snipmatch.rcp"; //$NON-NLS-1$
    public static final String EDITOR_ID = "org.eclipse.recommenders.snipmatch.rcp.editors.snippet"; //$NON-NLS-1$

    public static final String PREF_SNIPPETS_REPO_FETCH_URL = "snippets.repo.url"; //$NON-NLS-1$
    public static final String PREF_SNIPPETS_REPO_PUSH_URL = "snippets.repo.push.url"; //$NON-NLS-1$
    public static final String PREF_SNIPPETS_REPO_PUSH_BRANCH = "snippets.repo.push.branch"; //$NON-NLS-1$
    public static final String PREF_SEARCH_RESULTS_BACKGROUND = "org.eclipse.recommenders.snipmatch.rcp.searchResultBackgroundColor"; //$NON-NLS-1$
    public static final String PREF_SEARCH_BOX_BACKGROUND = "org.eclipse.recommenders.snipmatch.rcp.searchboxbackground"; //$NON-NLS-1$

    public static final String SNIPMATCH_CONTEXT_ID = "Snipmatch-Java-Context"; //$NON-NLS-1$
    public static final String EXT_POINT_PAGE_FACTORIES = "org.eclipse.recommenders.snipmatch.rcp.pageFactories"; //$NON-NLS-1$
}
